Hi Paul, I’ve been indexing an electrs pruned connected to a Blake 2b pruned node. It had been going slowly, but steadily. About 5 days into it, I was at 66% using about 39GB of storage. Then, I had a power outage. The node restarted fine, but electrs wouldn’t. So, I restarted it (mistake?). Now it’s at 32% indexed and running slowly, but still showing 39GB of storage used. Any wisdom for me? Cheers, Dan
OK update. Success! After the power outage setback, I started over: uninstalled Electrs pruned, and reinstalled it. But this time, I linked it at the beginning to my full node (SHA256) instead of the pruned node (2b), and it indexed much quicker - less than 6 hours. I watched it carefully as it got close to block 960,000 (99.8% done), and I went into settings (right click on the icon) and switched the link over to the pruned node. It was slow again at first, but sped up after the fork. It took a few more hours to finish up, and now it works perfectly. So, I wanted to share this little hack if anyone else has noticed very slow indexing on the pruned Electrs.
And, Paul, you’re a genius for solving this problem. Having two nodes running simultaneously on one machine is a game changer. Thank you, thank you.